@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2013 Red Hat, Inc.
 #
@@ -19,9 +18,9 @@ from watcherclient.common import utils
 from watcherclient import exceptions as exc
 
 
-CREATION_ATTRIBUTES = ['audit_template_uuid', 'host_aggregate',
-                       'deadline', 'audit_type', 'interval',
-                       'goal', 'strategy']
+CREATION_ATTRIBUTES = ['audit_template_uuid', 'audit_type', 'interval',
+                       'parameters', 'goal', 'strategy', 'auto_trigger',
+                       'name', 'start_time', 'end_time', 'force']
 
 
 class Audit(base.Resource):
@@ -37,11 +36,11 @@ class AuditManager(base.Manager):
         return '/v1/audits/%s' % id if id else '/v1/audits'
 
     def list(self, audit_template=None, limit=None, sort_key=None,
-             sort_dir=None, detail=False):
+             sort_dir=None, detail=False, goal=None, strategy=None,
+             marker=None):
         """Retrieve a list of audit.
 
-        :param audit_template: Name of the audit
-        :param name: Name of the audit
+        :param audit_template: Name of the audit template
         :param limit: The maximum number of results to return per
                       request, if:
 
@@ -59,15 +58,21 @@ class AuditManager(base.Manager):
         :param detail: Optional, boolean whether to return detailed information
                        about audits.
 
+        :param marker: Optional, UUID of the last audit in the previous page.
+
         :returns: A list of audits.
 
         """
         if limit is not None:
             limit = int(limit)
 
-        filters = utils.common_filters(limit, sort_key, sort_dir)
+        filters = utils.common_filters(limit, sort_key, sort_dir, marker)
         if audit_template is not None:
             filters.append('audit_template=%s' % audit_template)
+        if goal is not None:
+            filters.append('goal=%s' % goal)
+        if strategy is not None:
+            filters.append('strategy=%s' % strategy)
 
         path = ''
         if detail:
@@ -90,14 +95,14 @@ class AuditManager(base.Manager):
                 raise exc.InvalidAttribute()
         return self._create(self._path(), new)
 
-    def get(self, audit_id):
+    def get(self, audit):
         try:
-            return self._list(self._path(audit_id))[0]
+            return self._list(self._path(audit))[0]
         except IndexError:
             return None
 
-    def delete(self, audit_id):
-        return self._delete(self._path(audit_id))
+    def delete(self, audit):
+        return self._delete(self._path(audit))
 
-    def update(self, audit_id, patch):
-        return self._update(self._path(audit_id), patch)
+    def update(self, audit, patch):
+        return self._update(self._path(audit), patch)
